@@ -258,7 +258,8 @@ class Aligned(AnimGroup):
     def _adjust_t_range(self, lag_ratio, offset):
         end = max(anim.t_range.num_end for anim in self.anims)
         for anim in self.anims:
-            anim.t_range.set(0, end)
+            anim.shift_range(-anim.t_range.at)
+            anim.scale_range(end / anim.t_range.num_end)
 
 
 class Wait(Animation):
@@ -269,3 +270,21 @@ class Wait(Animation):
     '''
     def __init__(self, duration: float = 1, **kwargs):
         super().__init__(duration=duration, **kwargs)
+
+
+class Do(Animation):
+    '''
+    在动画的特定时间执行指定操作
+    '''
+    def __init__(self, func, *args, at: float = 0, detect_changes: bool = True, **kwargs):
+        super().__init__(at=at, duration=0)
+        self.func = func
+        self.args = args
+        self.detect_changes = detect_changes
+        self.kwargs = kwargs
+
+    def _time_fixed(self) -> None:
+        if self.detect_changes:
+            self.timeline.schedule_and_detect_changes(self.t_range.at, self.func, *self.args, **self.kwargs)
+        else:
+            self.timeline.schedule(self.t_range.at, self.func, *self.args, **self.kwargs)
