@@ -13,7 +13,7 @@ from collections import defaultdict
 from contextlib import contextmanager, nullcontext
 from contextvars import ContextVar
 from dataclasses import dataclass
-from typing import Callable, Iterable, overload
+from typing import Callable, Iterable, Self, overload
 
 import moderngl as mgl
 import numpy as np
@@ -28,7 +28,8 @@ from janim.anims.updater import updater_params_ctx
 from janim.camera.camera import Camera
 from janim.camera.camera_info import CameraInfo
 from janim.constants import (BLACK, DEFAULT_DURATION,
-                             DEFAULT_ITEM_TO_EDGE_BUFF, DOWN, SMALL_BUFF, UP)
+                             DEFAULT_ITEM_TO_EDGE_BUFF, DOWN, FOREVER,
+                             SMALL_BUFF, UP)
 from janim.exception import TimelineLookupError
 from janim.items.audio import Audio
 from janim.items.item import Item
@@ -140,7 +141,7 @@ class Timeline(metaclass=ABCMeta):
         text: str
         range: TimeRange
         kwargs: dict
-        subtitle: Text
+        subtitle: Text | TypstText
 
     @dataclass
     class AdditionalRenderCallsCallback:
@@ -169,6 +170,8 @@ class Timeline(metaclass=ABCMeta):
 
         self.debug_list: list[Item] = []
 
+        self.subtimeline_items: list[TimelineItem] = []
+
     @abstractmethod
     def construct(self) -> None:
         '''
@@ -271,7 +274,6 @@ class Timeline(metaclass=ABCMeta):
         与 :meth:`schedule` 类似，但是在调用 ``func`` 后会记录变化的物件的状态
         '''
         def wrapper(*args, **kwargs) -> None:
-            print(args, kwargs)
             func(*args, **kwargs)
             self.detect_changes_of_all()
         self.schedule(at, wrapper, *args, *kwargs)
@@ -352,7 +354,7 @@ class Timeline(metaclass=ABCMeta):
 
         - ``at_previous_frame`` 控制是在前一帧暂停（默认）还是在当前帧暂停
         - ``offset`` 表示偏移多少秒，例如 ``offset=2`` 则是当前位置 2s 后
-        - 在 GUI 界面中，可以使用 ``Ctrl+Z`` 快速移动到前一个暂停点，``Ctrl+C`` 快速移动到后一个
+        - 在 GUI 界面中，可以使用 ``Ctrl+左方向键`` 快速移动到前一个暂停点，``Ctrl+右方向键`` 快速移动到后一个
         '''
         self.pause_points.append(Timeline.PausePoint(self.current_time + offset, at_previous_frame))
 
@@ -439,10 +441,21 @@ class Timeline(metaclass=ABCMeta):
 
     def has_audio(self) -> bool:
         '''
-        是否有可以播放的音频
+        该 Timeline 自身是否有可以播放的音频
         '''
         return len(self.audio_infos) != 0
 
+    def has_audio_for_all(self) -> bool:
+        '''
+        考虑所有子 Timeline，是否有可以播放的音频
+        '''
+        if len(self.audio_infos) != 0:
+            return True
+        return any(
+            item._built.timeline.has_audio_for_all()
+            for item in self.subtimeline_items
+        )
+
     # endregion
 
     # region subtitle
@@ -726,10 +739,11 @@ class Timeline(metaclass=ABCMeta):
         '''
         隐藏显示中的所有物件
         '''
+        t = self.time_aligner.align_t(self.current_time)
         for appr in self.item_appearances.values():
             gaps = appr.visibility
             if len(gaps) % 2 == 1:
-                gaps.append(self.time_aligner.align_t(self.current_time))
+                gaps.append(t)
 
     def cleanup_display(self) -> None:
         from janim.utils.deprecation import deprecated
@@ -740,6 +754,13 @@ class Timeline(metaclass=ABCMeta):
         )
         self.hide_all()
 
+    def visible_items(self) -> list[Item]:
+        return [
+            item
+            for item, appr in self.item_appearances.items()
+            if len(appr.visibility) % 2 == 1
+        ]
+
     def add_additional_render_calls_callback(
         self,
         t_range: TimeRange,
@@ -833,7 +854,7 @@ class Timeline(metaclass=ABCMeta):
 
         time = self.fmt_time(self.current_time)
 
-        log.debug(f't={time}  {ext_msg}at construct.{self.get_construct_lineno()}')
+        log.info(f't={time}  {ext_msg}at construct.{self.get_construct_lineno()}')
 
     # endregion
 
@@ -872,7 +893,9 @@ class BuiltTimeline:
         )
         self.visible_additional_callbacks_segments = TimeSegments(
             self.timeline.additional_render_calls_callbacks,
-            lambda x: x.t_range
+            lambda x: (
+                x.t_range if x.t_range.end is not FOREVER else TimeRange(x.t_range.at, self.duration + 1)
+            )
         )
 
         self._time: float = 0
@@ -901,6 +924,7 @@ class BuiltTimeline:
         output_sample_count = math.floor(end * framerate) - math.floor(begin * framerate)
         result = np.zeros((output_sample_count, channels), dtype=np.int16)
 
+        # 合并自身的 audio
         for info in self.timeline.audio_infos:
             if end < info.range.at or begin > info.range.end:
                 continue
@@ -928,6 +952,14 @@ class BuiltTimeline:
 
             result += resize_preserving_order(data, output_sample_count)
 
+        # 合并子 Timeline 的 audio
+        for item in self.timeline.subtimeline_items:
+            built = item._built
+            frame_offset = int(item.at * fps)
+
+            data = built.get_audio_samples_of_frame(fps, framerate, frame - frame_offset, count=count)
+            result += resize_preserving_order(data, output_sample_count)
+
         return result
 
     def current_camera_info(self) -> CameraInfo:
@@ -976,8 +1008,12 @@ class BuiltTimeline:
                     # 这里也有可能产生 render_disabled 标记
                     additional: list[list[tuple[Item, Callable[[Item], None]]]] = []
                     for rcc in self.visible_additional_callbacks_segments.get(global_t):
-                        if not rcc.t_range.at <= global_t < rcc.t_range.end:
-                            continue
+                        if rcc.t_range.end is FOREVER:
+                            if not rcc.t_range.at <= global_t:
+                                continue
+                        else:
+                            if not rcc.t_range.at <= global_t < rcc.t_range.end:
+                                continue
                         additional.append(rcc.func())
                     # 剔除被标记 render_disabled 的物件，得到 render_items_final
                     render_datas_final: list[tuple[Item, Callable]] = []
@@ -1061,9 +1097,53 @@ class BuiltTimeline:
                     self.forward_to(tl2.end)
 
         这个例子中，在 ``Test`` 中插入了 ``Sub1`` 和 ``Sub2``
+
+        额外参数：
+
+        - ``delay``: 延迟多少秒开始该 Timeline 的播放
+        - ``keep_last_frame``: 是否在 Timeline 结束后仍然保留最后一帧的显示
         '''
         return TimelineItem(self, **kwargs)
 
+    def to_playback_control_item(self, **kwargs) -> TimelinePlaybackControlItem:
+        '''
+        使用该方法可以在一个 Timeline 中插入另一个 Timeline
+
+        并且与 :class:`~.Video` 类似，可以使用 ``start``、``stop`` 以及 ``seek`` 控制播放进度
+
+        例：
+
+        .. code-block:: python
+
+            class Sub(Timeline):
+                def construct(self):
+                    self.play(
+                        ItemUpdater(
+                            None,
+                            lambda p: Text(f'{p.global_t:.2f}')
+                        ),
+                        duration=8
+                    )
+
+
+            class Test(Timeline):
+                def construct(self):
+                    sub = Sub().build().to_playback_control_item().show()
+                    sub.start()
+                    self.forward(2)
+                    sub.start(speed=0.1)
+                    self.forward(2)
+                    sub.seek(0).start(speed=4)
+                    self.forward(2)
+
+        注意：在默认情况下未开始播放，需要使用 ``start`` 以开始播放
+
+        额外参数：
+
+        - ``keep_last_frame``: 是否在 Timeline 结束后仍然保留最后一帧的显示
+        '''
+        return TimelinePlaybackControlItem(self, **kwargs)
+
 
 class TimelineItem(Item):
     '''
@@ -1075,18 +1155,95 @@ class TimelineItem(Item):
             t = Animation.global_t_ctx.get() - item.at
             if 0 <= t <= item.duration:
                 item._built.render_all(self.data_ctx.get().ctx, t, blend_on=False)
+            elif item.keep_last_frame and t > item.duration:
+                item._built.render_all(self.data_ctx.get().ctx, item._built.duration, blend_on=False)
 
     renderer_cls = TIRenderer
 
-    def __init__(self, built: BuiltTimeline, *, delay: float = 0):
-        super().__init__()
+    def __init__(self, built: BuiltTimeline, *, delay: float = 0, keep_last_frame: bool = False, **kwargs):
+        super().__init__(**kwargs)
         self._built = built
         self.at = self.timeline.current_time + delay
         self.duration = self._built.duration
+        self.keep_last_frame = keep_last_frame
+
+        parent_timeline = Timeline.get_context(raise_exc=False)
+        if parent_timeline is not None:
+            parent_timeline.subtimeline_items.append(self)
 
     @property
     def end(self) -> float:
         return self.at + self.duration
 
 
-# TODO: TimelineAdvancedItem
+class PlaybackControl:
+    def __init__(self, *args, loop: bool = False, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.loop = loop
+
+        self.timeline = Timeline.get_context()
+
+        self.actions: list[tuple[float, float, float]] = []
+
+    def start(self, *, speed: int = 1) -> Self:
+        if not self.actions:
+            base = 0
+        else:
+            x, y, last_speed = self.actions[-1]
+            base = y + (self.timeline.current_time - x) * last_speed
+
+        self.actions.append((self.timeline.current_time,
+                             base,
+                             speed))
+        return self
+
+    def stop(self) -> Self:
+        self.start(speed=0)
+        return self
+
+    def seek(self, t: float) -> Self:
+        if not self.actions:
+            speed = 0
+        else:
+            speed = self.actions[-1][2]
+        self.actions.append((self.timeline.current_time,
+                             t,
+                             speed))
+        return self
+
+    def compute_time(self, t: float, total: float | None = None) -> float:
+        if not self.actions:
+            return 0
+        idx = bisect(self.actions, t, key=lambda v: v[0]) - 1
+        if idx < 0:
+            return 0
+        x, y, speed = self.actions[idx]
+        result = y + (t - x) * speed
+
+        if total is not None and self.loop:
+            return result % total
+        return result
+
+
+class TimelinePlaybackControlItem(PlaybackControl, Item):
+    '''
+    详见 :meth:`BuiltTimeline.to_playback_control_item`
+    '''
+
+    class TPCIRenderer(Renderer):
+        def render(self, item: TimelinePlaybackControlItem):
+            t = Animation.global_t_ctx.get()
+            t = item.compute_time(t, item.duration)
+            t = max(0, t)
+            if 0 <= t <= item.duration:
+                item._built.render_all(self.data_ctx.get().ctx, t, blend_on=False)
+            elif item.keep_last_frame and t > item.duration:
+                item._built.render_all(self.data_ctx.get().ctx, item._built.duration, blend_on=False)
+
+    renderer_cls = TPCIRenderer
+
+    def __init__(self, built: BuiltTimeline, *, keep_last_frame: bool = False, **kwargs):
+        super().__init__(**kwargs)
+        self._built = built
+        self.duration = self._built.duration
+        self.keep_last_frame = keep_last_frame
