@@ -178,11 +178,9 @@ class _DataUpdater(ItemAnimation):
         lag_ratio: float,
         index: int,
         count: int,
-        *,
-        show_at_begin: bool,
-        hide_at_end: bool
+        **kwargs
     ):
-        super().__init__(item, show_at_begin=show_at_begin, hide_at_end=hide_at_end)
+        super().__init__(item, **kwargs)
         self._generate_by = generate_by
         self.func = func
         self.extra_data = extra_data
@@ -219,6 +217,7 @@ class GroupUpdater[T: Item](Animation):
         func: GroupUpdaterFn[T],
         *,
         show_at_begin: bool = True,
+        hide_at_end: bool = False,
         become_at_end: bool = True,
         **kwargs
     ):
@@ -226,6 +225,7 @@ class GroupUpdater[T: Item](Animation):
         self.item = item
         self.func = func
         self.show_at_begin = show_at_begin
+        self.hide_at_end = hide_at_end
         self.become_at_end = become_at_end
 
         self.applied: bool = False
@@ -249,7 +249,7 @@ class GroupUpdater[T: Item](Animation):
             for item in self.item.walk_self_and_descendants()
         ]
         updaters = [
-            _GroupUpdater(self, item, data, stacks, show_at_begin=self.show_at_begin)
+            _GroupUpdater(self, item, data, stacks, show_at_begin=self.show_at_begin, hide_at_end=self.hide_at_end)
             for item, data in zip(self.item.walk_self_and_descendants(), self.data.walk_self_and_descendants())
         ]
 
@@ -288,10 +288,9 @@ class _GroupUpdater(ApplyAligner):
         item: Item,
         data: Item,
         stacks: list[AnimStack],
-        *,
-        show_at_begin: bool
+        **kwargs
     ):
-        super().__init__(item, stacks, show_at_begin=show_at_begin)
+        super().__init__(item, stacks, **kwargs)
         self._generate_by = generate_by
         self.data = data
 
@@ -316,9 +315,19 @@ class MethodUpdater(Animation):
         GetAttr = 0
         Call = 1
 
-    def __init__(self, item: Item, **kwargs):
+    def __init__(
+        self,
+        item: Item,
+        show_at_begin: bool = True,
+        hide_at_end: bool = False,
+        become_at_end: bool = True,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.item = item
+        self.show_at_begin = show_at_begin
+        self.hide_at_end = hide_at_end
+        self.become_at_end = become_at_end
 
         self.updaters: list[tuple[str | None, Callable, tuple, dict, bool | None]] = []
         self.grouply: bool = False
@@ -385,12 +394,18 @@ class MethodUpdater(Animation):
                 self.item,
                 self.updater,
                 extra=lambda item: item is self.item,   # 只有根物件的 extra_data 为 True，用于辅助 root_only
-                root_only=False
+                root_only=False,
+                show_at_begin=self.show_at_begin,
+                hide_at_end=self.hide_at_end,
+                become_at_end=self.become_at_end
             )
         else:
             sub_updater = GroupUpdater(
                 self.item,
                 self.updater,
+                show_at_begin=self.show_at_begin,
+                hide_at_end=self.hide_at_end,
+                become_at_end=self.become_at_end
             )
 
         sub_updater._generate_by = self
@@ -453,12 +468,11 @@ class ItemUpdater(Animation):
         if self.item is None:
             return
 
-        # 在动画开始时自动隐藏，在动画结束时自动显示
-        # 可以将 ``hide_on_begin`` 和 ``show_on_end`` 置为 ``False`` 以禁用
-        if self.hide_at_begin:
-            self.timeline.schedule(self.t_range.at, self.item.hide)
-        if self.show_at_end:
-            self.timeline.schedule(self.t_range.end, self.item.show)
+        # 因为如果需要在动画结束后替换物件，那么前后的后代物件可能会不同
+        # 因此这里采用先记录后代物件的方式，再 schedule 对这些记录的物件的隐藏和显示
+        # 而不是直接 schedule 物件的隐藏和显示
+        hide_items = list(self.item.walk_self_and_descendants())
+        show_items = hide_items
 
         # 在动画结束后，自动使用动画最后一帧的物件替换原有的
         if self.become_at_end and self.t_range.end is not FOREVER:
@@ -467,10 +481,18 @@ class ItemUpdater(Animation):
                                self.t_range,
                                None,
                                self) as params:
-                self.item.become(self.call(params))
-                for item in self.item.walk_self_and_descendants():
+                self.item.become(self.call(params), auto_visible=False)
+                show_items = list(self.item.walk_self_and_descendants())
+                for item in show_items:
                     self.timeline.item_appearances[item].stack.detect_change(item, self.t_range.end, force=True)
 
+        # 在动画开始时自动隐藏，在动画结束时自动显示
+        # 可以将 ``hide_on_begin`` 和 ``show_on_end`` 置为 ``False`` 以禁用
+        if self.hide_at_begin:
+            self.timeline.schedule(self.t_range.at, self.timeline.hide, *hide_items, root_only=True)
+        if self.show_at_end:
+            self.timeline.schedule(self.t_range.end, self.timeline.show, *show_items, root_only=True)
+
     def call(self, p: UpdaterParams) -> Item:
         ret = self.func(p)
         if not isinstance(ret, Item):
@@ -617,6 +639,9 @@ class _StepUpdater(ItemAnimation):
     def global_t_to_n(self, global_t: float) -> int:
         return max(0, int((global_t - self.t_range.at) // self.step))
 
+    def n_to_global_t(self, n: int) -> float:
+        return n * self.step + self.t_range.at
+
     def compute(self, data: Item, global_t: float, *, generate_temporary_cache: bool = False) -> None:
         n = self.global_t_to_n(global_t)
         at_block = n // self.pcache_base
@@ -657,7 +682,7 @@ class _StepUpdater(ItemAnimation):
             )
 
         for computing_n in rg:
-            with StepUpdaterParams(global_t,
+            with StepUpdaterParams(self.n_to_global_t(computing_n),
                                    self.t_range,
                                    computing_n,
                                    self) as params:
