@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 import inspect
-from typing import Callable, Iterable, Self
+import types
+from typing import TYPE_CHECKING, Callable, Iterable, Self
 
 import numpy as np
 
@@ -21,9 +22,13 @@ from janim.utils.data import AlignedData, Array
 from janim.utils.iterables import resize_and_repeatedly_extend
 from janim.utils.paths import PathFunc, straight_path
 from janim.utils.signal import Signal
+from janim.utils.simple_functions import clip
 from janim.utils.space_ops import (angle_of_vector, get_norm, normalize,
                                    rotation_between_vectors, rotation_matrix)
 
+if TYPE_CHECKING:
+    from janim.camera.camera import Camera
+
 _ = get_local_strings('points')
 
 type PointsFn = Callable[[np.ndarray], VectArray]
@@ -86,8 +91,11 @@ class Cmpt_Points[ItemT](Component[ItemT]):
         *,
         path_func: PathFunc = straight_path
     ) -> None:
-        if not cmpt1._points.is_share(cmpt2._points):
-            self.set(path_func(cmpt1.get(), cmpt2.get(), alpha))
+        if not cmpt1._points.is_share(cmpt2._points) or not cmpt1._points.is_share(self._points):
+            if cmpt1._points.is_share(cmpt2._points):
+                self._points = cmpt1._points.copy()
+            else:
+                self.set(path_func(cmpt1.get(), cmpt2.get(), alpha))
 
     # region 点数据 | Points
 
@@ -667,11 +675,11 @@ class Cmpt_Points[ItemT](Component[ItemT]):
         depth: float | None = None,
         **kwargs
     ) -> Self:
-        if width:
+        if width is not None:
             self.set_width(width, stretch=True, **kwargs)
-        if height:
+        if height is not None:
             self.set_height(height, stretch=True, **kwargs)
-        if depth:
+        if depth is not None:
             self.set_depth(depth, stretch=True, **kwargs)
         return self
 
@@ -788,6 +796,8 @@ class Cmpt_Points[ItemT](Component[ItemT]):
         '''
         通过旋转和缩放，使得物件的起点和终点被置于 ``start`` 和 ``end``
         '''
+        start, end = np.asarray(start), np.asarray(end)
+
         curr_start, curr_end = self.get_start(), self.get_end()
         curr_vect = curr_end - curr_start
         if np.all(curr_vect == 0):
@@ -807,6 +817,95 @@ class Cmpt_Points[ItemT](Component[ItemT]):
         self.shift(start - self.get_start())
         return self
 
+    @property
+    @set.self_refresh
+    @refresh.register
+    def unit_normal(self) -> np.ndarray:
+        '''
+        计算三维点集的拟合平面的单位法向量
+        '''
+        points = self.get()
+
+        # 质心
+        centroid = np.mean(points, axis=0)
+
+        # 协方差矩阵
+        A = points - centroid
+        C = A.T @ A
+
+        # 求特征值和特征向量，最小特征值对应的特征向量就是法向量
+        eigvals, eigvecs = np.linalg.eigh(C)
+        normal = eigvecs[:, np.argmin(eigvals)]
+        return normalize(normal)
+
+    def face_to_camera(
+        self,
+        camera: Camera | types.EllipsisType = ...,
+        *,
+        rotate: float = 0,
+        inverse: bool = False,
+        normal_vector: Vect | types.EllipsisType = ...,
+        about_point: Vect | None = None,
+        about_edge: Vect | None = ORIGIN,
+        root_only: bool = False,
+    ) -> Self:
+        '''
+        使物件面向摄像机
+
+        实用参数：
+
+        - ``rotate``：在面向摄像机的基础上，绕摄像机视角旋转的角度
+
+        - ``inverse``：是否让物件背向摄像机
+
+        - 视 ``about_point`` 为参考点，若其为 ``None``，则将物件在 ``about_edge`` 方向上的边界作为 ``about_point``
+
+        可手动指定 ``camera`` 和法向量 ``normal_vector``，若无则会自动获取：
+
+        - ``camera`` 默认为时间轴的 ``self.camera``
+
+        - ``normal_vector`` 默认通过 :meth:`unit_normal` 计算
+        '''
+        if camera is ...:
+            from janim.anims.timeline import Timeline
+            camera = Timeline.get_context().camera.current()
+
+        if normal_vector is ...:
+            vectors = [
+                cmpt.unit_normal
+                for cmpt in self.walk_same_cmpt_of_self_and_descendants_without_mock(root_only)
+                if cmpt.has()
+            ]
+            normal_vector = np.sum(vectors, axis=0)
+            if np.allclose(normal_vector, 0):
+                normal_vector = normalize(vectors[0])
+            else:
+                normal_vector = normalize(normal_vector)
+
+        if inverse:
+            normal_vector = -normal_vector
+
+        info = camera.points.info
+        camera_axis = info.camera_location - info.center
+        camera_transform = rotation_between_vectors(normal_vector, camera_axis)
+
+        up = np.cross(normal_vector, RIGHT)
+        if inverse:
+            up = -up
+        mapped_up = up @ camera_transform.T
+
+        rot_transform = rotation_between_vectors(mapped_up, info.vertical_vect)
+        if rotate != 0:
+            rot_transform @= rotation_matrix(rotate, camera_axis)
+
+        self.apply_matrix(
+            rot_transform @ camera_transform,
+            about_point=about_point,
+            about_edge=about_edge,
+            root_only=root_only
+        )
+        return self
+
     # endregion
 
     # region 位移 | movement
@@ -864,7 +963,7 @@ class Cmpt_Points[ItemT](Component[ItemT]):
     def move_to_by_indicator(
         self,
         indicator: Item,
-        target: Item,
+        target: Item | Vect,
         *,
         aligned_edge: Vect = ORIGIN,
         coor_mask: Iterable = (1, 1, 1),
@@ -1163,15 +1262,72 @@ class Cmpt_Points[ItemT](Component[ItemT]):
 
     def shift_onto_screen(self, **kwargs) -> Self:
         space_lengths = [Config.get.frame_x_radius, Config.get.frame_y_radius]
+        buff = kwargs.get("buff", DEFAULT_ITEM_TO_EDGE_BUFF)
         for vect in UP, DOWN, LEFT, RIGHT:
             dim = np.argmax(np.abs(vect))
-            buff = kwargs.get("buff", DEFAULT_ITEM_TO_EDGE_BUFF)
             max_val = space_lengths[dim] - buff
             edge_center = self.box.get(vect)
             if np.dot(edge_center, vect) > max_val:
                 self.to_border(vect, **kwargs)
         return self
 
+    def shift_onto_screen_along_direction(
+        self,
+        direction: Vect,
+        *,
+        buff: float = DEFAULT_ITEM_TO_EDGE_BUFF
+    ) -> Self:
+        center = self.box.center
+        x_radius = Config.get.frame_x_radius - self.box.width / 2 - buff
+        y_radius = Config.get.frame_y_radius - self.box.height / 2 - buff
+
+        # 如果已经在内部了，那么就不用移动了
+        if -x_radius <= center[0] <= x_radius and -y_radius <= center[1] <= y_radius:
+            return self
+
+        # (X, Y, Distance)
+        candidates: list[tuple[float, float, float]] = []
+
+        # 计算 direction 方向的直线与两条竖线的交点
+        for x in (-x_radius, x_radius):
+            # 如果 direction 几乎垂直，那么直接将横向吸附点加到 candidates 中
+            # 否则就计算交点加到 candidates 中
+            if np.isclose(direction[0], 0):
+                y = center[1]
+                dist = abs(x - center[0])
+            else:
+                y = center[1] + direction[1] * (x - center[0]) / direction[0]
+                if -y_radius <= y <= y_radius:
+                    dist = 0
+                else:
+                    dist = min(abs(y + y_radius), abs(y - y_radius))
+
+            candidates.append((x, clip(y, -y_radius, y_radius), dist))
+
+        # 计算 direction 方向的直线与两条横线的交点
+        for y in (-y_radius, y_radius):
+            # 如果 direction 几乎水平，那么直接将纵向吸附点加到 candidates 中
+            # 否则就计算交点加到 candidates 中
+            if np.isclose(direction[1], 0):
+                x = center[0]
+                dist = abs(y - center[1])
+            else:
+                x = center[0] + direction[0] * (y - center[1]) / direction[1]
+                if -x_radius <= x <= x_radius:
+                    dist = 0
+                else:
+                    dist = min(abs(x + x_radius), abs(x - x_radius))
+
+            candidates.append((clip(x, -x_radius, x_radius), y, dist))
+
+        # 筛选出最佳的位置
+        min_dist = min(p[2] for p in candidates)
+        filtered = [p for p in candidates if np.isclose(p[2], min_dist)]
+        best = min(filtered, key=lambda p: get_norm(p[:2] - center[:2]))
+
+        self.move_to([*best[:2], center[2]])
+        return self
+
     def set_coord(self, value: float, *, dim: int, direction: Vect = ORIGIN, root_only=False) -> Self:
         curr = self.box.coord(dim, direction)
         shift_vect = np.zeros(3)
@@ -1187,3 +1343,5 @@ class Cmpt_Points[ItemT](Component[ItemT]):
 
     def set_z(self, z: float, direction: Vect = ORIGIN) -> Self:
         return self.set_coord(z, dim=2, direction=direction)
+
+    # endregion
