@@ -58,8 +58,11 @@ class Cmpt_Radius[ItemT](Component[ItemT]):
         return AlignedData(cmpt1_copy, cmpt2_copy, cmpt1_copy.copy())
 
     def interpolate(self, cmpt1: Cmpt_Radius, cmpt2: Cmpt_Radius, alpha: float, *, path_func=None) -> None:
-        if not cmpt1._radii.is_share(cmpt2._radii):
-            self.set(interpolate(cmpt1.get(), cmpt2.get(), alpha), root_only=True)
+        if not cmpt1._radii.is_share(cmpt2._radii) or not cmpt1._radii.is_share(self._radii):
+            if cmpt1._radii.is_share(cmpt2._radii):
+                self._radii = cmpt1._radii.copy()
+            else:
+                self.set(interpolate(cmpt1.get(), cmpt2.get(), alpha), root_only=True)
 
     # region 半径数据 | Radii
 
@@ -121,4 +124,16 @@ class Cmpt_Radius[ItemT](Component[ItemT]):
     def count(self) -> int:
         return len(self.get())
 
+    def scale(self, factor: float, *, root_only: bool = False) -> Self:
+        '''
+        缩放线条半径数据
+        '''
+        self._radii.data = self._radii.data * factor
+
+        if not root_only:
+            for cmpt in self.walk_same_cmpt_of_descendants_without_mock():
+                cmpt._radii.data = cmpt._radii.data * factor
+
+        return self
+
     # endregion
