@@ -18,10 +18,13 @@ import os
 import sys
 import time
 import traceback
-from bisect import bisect_left
+from bisect import bisect_right
+from contextlib import contextmanager, nullcontext
 
-from PySide6.QtCore import QByteArray, QEvent, Qt, QTimer, Signal
-from PySide6.QtGui import QAction, QCloseEvent, QHideEvent, QIcon, QShowEvent
+from PySide6.QtCore import (QByteArray, QEvent, QPoint, QSettings, Qt, QTimer,
+                            Signal)
+from PySide6.QtGui import (QAction, QCloseEvent, QGuiApplication, QHideEvent,
+                           QIcon, QShowEvent)
 from PySide6.QtWidgets import (QApplication, QCompleter, QLabel, QLineEdit,
                                QMainWindow, QMessageBox, QPushButton,
                                QSizePolicy, QSplitter, QStackedLayout, QWidget)
@@ -44,8 +47,9 @@ from janim.gui.timeline_view import TimelineView
 from janim.locale.i18n import get_local_strings
 from janim.logger import log
 from janim.render.writer import AudioWriter, VideoWriter, merge_video_and_audio
-from janim.utils.config import cli_config
-from janim.utils.file_ops import get_janim_dir, open_file
+from janim.utils.config import Config, cli_config
+from janim.utils.file_ops import get_janim_dir, getfile_or_empty, open_file
+from janim.utils.reload import reset_reloads_state
 
 _ = get_local_strings('anim_viewer')
 
@@ -70,6 +74,7 @@ class AnimViewer(QMainWindow):
         parent: QWidget | None = None
     ):
         super().__init__(parent)
+        self.code_file_path = getfile_or_empty(built.timeline.__class__)
 
         self.setup_ui()
         self.setup_play_timer()
@@ -146,7 +151,7 @@ class AnimViewer(QMainWindow):
         if self.play_timer.skip_enabled:
             self.play_timer.take_skip_count()
 
-        if self.built.timeline.has_audio() and self.audio_player is None:
+        if self.built.timeline.has_audio_for_all() and self.audio_player is None:
             self.audio_player = AudioPlayer(self.built.cfg.audio_framerate,
                                             self.built.cfg.audio_channels,
                                             self.built.cfg.preview_fps)
@@ -167,6 +172,8 @@ class AnimViewer(QMainWindow):
         self.setWindowFlags(Qt.WindowType.Window)
         self.timeline_view.setFocus()
 
+        self.load_options()
+
         # 在 macOS 中，设置了 WindowStaysOnTopHint 后，点击窗口会把 Tool 窗口遮挡
         # 所以这里监听窗口事件，只要点击了窗口，就手动把 Tool 窗口放到最上面
         if sys.platform == "darwin":
@@ -174,50 +181,80 @@ class AnimViewer(QMainWindow):
 
     def setup_menu_bar(self) -> None:
         menu_bar = self.menuBar()
-        menu_functions = menu_bar.addMenu(_('Functions(&F)'))
 
-        self.action_stay_on_top = menu_functions.addAction(_('Stay on top(&T)'))
+        menu_file = menu_bar.addMenu(_('File(&F)'))
+
+        self.action_rebuild = menu_file.addAction(_('Rebuild(&L)'))
+        self.action_rebuild.setShortcut('Ctrl+L')
+        self.action_rebuild.setAutoRepeat(False)
+
+        menu_file.addSeparator()
+
+        self.action_export = menu_file.addAction(_('Export(&E)'))
+        self.action_export.setShortcut('Ctrl+S')
+        self.action_export.setAutoRepeat(False)
+
+        self.action_capture = menu_file.addAction(_('Capture(&C)'))
+        self.action_capture.setShortcut('Ctrl+Alt+S')
+        self.action_capture.setAutoRepeat(False)
+
+        menu_file.addSeparator()
+
+        self.action_set_in_point = menu_file.addAction(_('Set In Point(&I)'))
+        self.action_set_in_point.setShortcut('[')
+        self.action_set_in_point.setAutoRepeat(False)
+
+        self.action_set_out_point = menu_file.addAction(_('Set Out Point(&O)'))
+        self.action_set_out_point.setShortcut(']')
+        self.action_set_out_point.setAutoRepeat(False)
+
+        self.action_reset_inout_point = menu_file.addAction(_('Reset In/Out Point(&R)'))
+        self.action_reset_inout_point.setAutoRepeat(False)
+
+        menu_view = menu_bar.addMenu(_('View(&V)'))
+
+        self.action_stay_on_top = menu_view.addAction(_('Stay on top(&T)'))
         self.action_stay_on_top.setCheckable(True)
         self.action_stay_on_top.setShortcut('Ctrl+T')
         self.action_stay_on_top.setAutoRepeat(False)
 
-        self.action_frame_skip = menu_functions.addAction(_('Frame skip(&P)'))
+        self.action_frame_skip = menu_view.addAction(_('Frame skip(&P)'))
         self.action_frame_skip.setCheckable(True)
         self.action_frame_skip.setShortcut('Ctrl+P')
         self.action_frame_skip.setAutoRepeat(False)
 
-        menu_functions.addSeparator()
+        menu_tools = menu_bar.addMenu(_('Tools(&T)'))
 
-        self.action_rebuild = menu_functions.addAction(_('Rebuild(&L)'))
-        self.action_rebuild.setShortcut('Ctrl+L')
-        self.action_rebuild.setAutoRepeat(False)
-
-        menu_functions.addSeparator()
-
-        self.action_select = menu_functions.addAction(_('Subitem selector(&S)'))
-        self.action_select.setShortcut('Ctrl+S')
+        self.action_select = menu_tools.addAction(_('Subitem selector(&I)'))
+        self.action_select.setShortcut('Ctrl+I')
         self.action_select.setAutoRepeat(False)
         self.selector: Selector | None = None
 
-        self.action_painter = menu_functions.addAction(_('Draw(&D)'))
+        self.action_painter = menu_tools.addAction(_('Draw(&D)'))
         self.action_painter.setShortcut('Ctrl+D')
         self.action_painter.setAutoRepeat(False)
 
-        self.action_richtext_edit = menu_functions.addAction(_('Rich text editor(&R)'))
+        self.action_richtext_edit = menu_tools.addAction(_('Rich text editor(&R)'))
         self.action_richtext_edit.setShortcut('Ctrl+R')
         self.action_richtext_edit.setAutoRepeat(False)
 
-        self.action_font_table = menu_functions.addAction(_('Font list(&F)'))
+        self.action_font_table = menu_tools.addAction(_('Font list(&F)'))
         self.action_font_table.setShortcut('Ctrl+F')
         self.action_font_table.setAutoRepeat(False)
 
-        self.action_color_widget = menu_functions.addAction(_('Color(&O)'))
+        self.action_color_widget = menu_tools.addAction(_('Color(&O)'))
         self.action_color_widget.setShortcut('Ctrl+O')
         self.action_color_widget.setAutoRepeat(False)
 
+        menu_tools.addSeparator()
+
+        self.action_copy_time = menu_tools.addAction(_('Copy time point(&T)'))
+        self.action_copy_time.setShortcut('T')
+        self.action_copy_time.setAutoRepeat(False)
+
     def setup_status_bar(self) -> None:
         self.fps_label = QLabel()
-        self.time_label = QLabel()
+        self.time_label = QPushButton()
         self.name_edit = QLineEdit()
 
         self.btn_capture = QPushButton()
@@ -319,6 +356,32 @@ class AnimViewer(QMainWindow):
 
     # endregion (setup_ui)
 
+    # region options
+
+    def load_options(self) -> None:
+        settings = QSettings(os.path.join(Config.get.temp_dir, 'anim_viewer.ini'), QSettings.Format.IniFormat)
+        settings.beginGroup(self.code_file_path)
+        frame_skip = settings.value('frame_skip', False, type=bool)
+        settings.endGroup()
+
+        self.action_frame_skip.setChecked(frame_skip)
+        if frame_skip:
+            # 在渲染后才真正启用 frame_skip，避免启动时跳过太多帧
+            def slot() -> None:
+                self.play_timer.start_precise_timer()   # 重置时间
+                self.play_timer.set_skip_enabled(True)
+                self.glw.rendered.disconnect(slot)
+
+            self.glw.rendered.connect(slot)
+
+    def save_options(self) -> None:
+        settings = QSettings(os.path.join(Config.get.temp_dir, 'anim_viewer.ini'), QSettings.Format.IniFormat)
+        settings.beginGroup(self.code_file_path)
+        settings.setValue('frame_skip', self.action_frame_skip.isChecked())
+        settings.endGroup()
+
+    # endregion
+
     # region play_timer
 
     def setup_play_timer(self) -> None:
@@ -351,14 +414,20 @@ class AnimViewer(QMainWindow):
     # region slots
 
     def setup_slots(self) -> None:
+        self.action_rebuild.triggered.connect(self.on_rebuild_triggered)
+        self.action_export.triggered.connect(self.on_export_clicked)
+        self.action_capture.triggered.connect(self.on_capture_clicked)
+        self.action_set_in_point.triggered.connect(self.timeline_view.set_in_point)
+        self.action_set_out_point.triggered.connect(self.timeline_view.set_out_point)
+        self.action_reset_inout_point.triggered.connect(self.timeline_view.reset_inout_point)
         self.action_stay_on_top.toggled.connect(self.on_stay_on_top_toggled)
         self.action_frame_skip.toggled.connect(self.on_frame_skip_toggled)
-        self.action_rebuild.triggered.connect(self.on_rebuild_triggered)
         self.action_select.triggered.connect(self.on_select_triggered)
         self.connect_action_widget(self.action_painter, Painter)
         self.connect_action_widget(self.action_richtext_edit, RichTextEditor)
         self.connect_action_widget(self.action_font_table, FontTable)
         self.connect_action_widget(self.action_color_widget, ColorWidget)
+        self.action_copy_time.triggered.connect(self.on_copy_time_triggered)
 
         self.timeline_view.value_changed.connect(self.on_value_changed)
         self.timeline_view.dragged.connect(lambda: self.set_play_state(False))
@@ -368,6 +437,7 @@ class AnimViewer(QMainWindow):
         self.glw.rendered.connect(self.on_glw_rendered)
         self.glw.error_occurred.connect(self.on_error_occurred)
         self.name_edit.editingFinished.connect(self.on_name_edit_finished)
+        self.time_label.clicked.connect(self.on_copy_time_triggered)
         self.btn_capture.clicked.connect(self.on_capture_clicked)
         self.btn_export.clicked.connect(self.on_export_clicked)
 
@@ -404,6 +474,7 @@ class AnimViewer(QMainWindow):
         if module_name == '__main__':
             module_name = '__janim_main__'
 
+        reset_reloads_state()
         loader = importlib.machinery.SourceFileLoader(module_name, module.__file__)
         module = loader.load_module()
         timeline_class = getattr(module, name, None)
@@ -426,6 +497,8 @@ class AnimViewer(QMainWindow):
             return
 
         range = self.timeline_view.range
+        inout_point = self.timeline_view.inout_point
+
         self.set_built(built)
 
         if not stay_same:
@@ -445,6 +518,11 @@ class AnimViewer(QMainWindow):
             # 那么仍保留原来的显示范围，使得 0~1s 的显示位置不变，虽然显示范围超出了持续时间
             self.timeline_view.range = range
 
+            # 设置回 入点/出点 信息，并根据当前的总时长进行调整
+            # 后一个判断对应“如果入点比总时长还大，那么就不设置回 入点/出点 信息了”
+            if inout_point is not None and inout_point[0] < built.duration:
+                self.timeline_view.inout_point = (inout_point[0], min(inout_point[1], built.duration))
+
         import gc
 
         from janim.cli import get_all_timelines_from_module
@@ -502,6 +580,32 @@ class AnimViewer(QMainWindow):
 
         action.triggered.connect(triggered)
 
+    def on_copy_time_triggered(self) -> None:
+        view = self.timeline_view
+        clipboard = QGuiApplication.clipboard()
+        clipboard.setText(f'{view.progress_to_time(view.progress()):.2f}')
+
+        self.copied_label = QLabel(_('Copied!'))
+        self.copied_label.setStyleSheet(
+            '''
+            background-color: #232629;
+            border: 1px solid white;
+            padding: 2px 4px;
+            border-radius: 6px;
+            font-size: 12px;
+            '''
+        )
+        self.copied_label.setWindowFlag(Qt.WindowType.ToolTip)
+        self.copied_label.adjustSize()
+
+        pos = QPoint(self.time_label.width() // 2, self.time_label.height() // 2)
+        pos = self.time_label.mapToGlobal(pos)
+        pos -= QPoint(self.copied_label.width() // 2, self.copied_label.height() // 2)
+
+        self.copied_label.move(pos)
+        self.copied_label.show()
+        QTimer.singleShot(500, self.copied_label.hide)
+
     # endregion (slots-menu)
 
     # region slots-anim
@@ -535,7 +639,7 @@ class AnimViewer(QMainWindow):
             # 这里使用 QTimer.singleShot 是为了让这个消息尽量在 traceback 后再显示
             QTimer.singleShot(
                 0,
-                lambda: log.warning(_('An error occurred during rendering, playback stopped'))
+                lambda: log.error(_('An error occurred during rendering, playback stopped'))
             )
 
         # 没把这个放在 if 分支里，是为了在 inactive 的时候也设置为 True
@@ -549,21 +653,29 @@ class AnimViewer(QMainWindow):
 
     def on_play_timer_timeout(self) -> None:
         played_count = 1 + self.play_timer.take_skip_count()
-        if self.built.timeline.has_audio():
+        prev_progress = self.timeline_view.progress()
+        curr_progress = prev_progress + played_count
+
+        # 播放 prev_progress ~ curr_progress 之间的音频
+        if self.built.timeline.has_audio_for_all():
             samples = self.built.get_audio_samples_of_frame(self.built.cfg.preview_fps,
                                                             self.built.cfg.audio_framerate,
-                                                            self.timeline_view.progress(),
+                                                            prev_progress,
                                                             count=played_count)
             self.audio_player.write(samples.tobytes())
 
-        self.timeline_view.set_progress(self.timeline_view.progress() + played_count)
-
+        # 查找 (prev_progress, curr_progress] 的区段的第一个 pause_point，如果有则暂停到特定位置
         if self.pause_progresses:
-            progress = self.timeline_view.progress()
-            idx = bisect_left(self.pause_progresses, progress)
-            if idx < len(self.pause_progresses) and self.pause_progresses[idx] == progress:
+            # 找到第一个大于 prev_progress 的位置
+            idx = bisect_right(self.pause_progresses, prev_progress)
+            # 确认这个数是否 <= curr_progress
+            if idx < len(self.pause_progresses) and self.pause_progresses[idx] <= curr_progress:
+                curr_progress = self.pause_progresses[idx]
                 self.play_timer.stop()
 
+        self.timeline_view.set_progress(curr_progress)
+
+        # 如果播放到了结尾则停止 timer
         if self.timeline_view.at_end():
             self.play_finished.emit()
             self.play_timer.stop()
@@ -588,9 +700,10 @@ class AnimViewer(QMainWindow):
         ret = False
         t = self.timeline_view.progress_to_time(self.timeline_view.progress())
         try:
-            # 这里每次截图都重新构建一下，因为如果复用原来的对象会使得和 GUI 的上下文冲突
-            built = self.built.timeline.__class__().build()
-            built.capture(t, transparent=transparent).save(file_path)
+            with self.change_export_size(dialog.pixel_size()) if dialog.has_size_set() else nullcontext():
+                # 这里每次截图都重新构建一下，因为如果复用原来的对象会使得和 GUI 的上下文冲突
+                built = self.built.timeline.__class__().build()
+                built.capture(t, transparent=transparent).save(file_path)
 
         except Exception as e:
             if not isinstance(e, ExitException):
@@ -609,15 +722,16 @@ class AnimViewer(QMainWindow):
     def on_export_clicked(self) -> None:
         self.play_timer.stop()
 
-        dialog = ExportDialog(self.built, self)
+        dialog = ExportDialog(self.built, self.timeline_view.inout_point is not None, self)
         ret = dialog.exec()
         if not ret:
             return
 
         file_path = dialog.file_path()
         cli_config.fps = dialog.fps()
+        using_inout_point = dialog.using_inout_point()
         hwaccel = dialog.hwaccel()
-        video_with_audio = (self.built.timeline.has_audio() and not file_path.endswith('gif'))
+        video_with_audio = (self.built.timeline.has_audio_for_all() and not file_path.endswith('gif'))
 
         QMessageBox.information(self,
                                 _('Note'),
@@ -626,24 +740,29 @@ class AnimViewer(QMainWindow):
         QApplication.processEvents()
         ret = False
         try:
-            built = self.built.timeline.__class__().build()
+            with self.change_export_size(dialog.pixel_size()) if dialog.has_size_set() else nullcontext():
+                built = self.built.timeline.__class__().build()
 
-            if video_with_audio:
-                video_writer = VideoWriter(built)
-                video_writer.write_all(file_path, hwaccel=hwaccel, _keep_temp=True)
+                args = [file_path]
+                if using_inout_point:
+                    args += self.timeline_view.inout_point
 
-                audio_file_path = os.path.splitext(file_path)[0] + '.mp3'
+                if video_with_audio:
+                    video_writer = VideoWriter(built)
+                    video_writer.write_all(*args, hwaccel=hwaccel, _keep_temp=True)
 
-                audio_writer = AudioWriter(built)
-                audio_writer.write_all(audio_file_path, _keep_temp=True)
+                    audio_file_path = os.path.splitext(file_path)[0] + '.mp3'
 
-                merge_video_and_audio(built.cfg.ffmpeg_bin,
-                                      video_writer.temp_file_path,
-                                      audio_writer.temp_file_path,
-                                      video_writer.final_file_path)
-            else:
-                video_writer = VideoWriter(built)
-                video_writer.write_all(file_path, hwaccel=hwaccel)
+                    audio_writer = AudioWriter(built)
+                    audio_writer.write_all(audio_file_path, _keep_temp=True)
+
+                    merge_video_and_audio(built.cfg.ffmpeg_bin,
+                                          video_writer.temp_file_path,
+                                          audio_writer.temp_file_path,
+                                          video_writer.final_file_path)
+                else:
+                    video_writer = VideoWriter(built)
+                    video_writer.write_all(*args, hwaccel=hwaccel)
 
         except Exception as e:
             if not isinstance(e, ExitException):
@@ -661,6 +780,15 @@ class AnimViewer(QMainWindow):
             if dialog.open():
                 open_file(file_path)
 
+    @contextmanager
+    def change_export_size(self, size: tuple[int, int]):
+        old_size = cli_config.pixel_width, cli_config.pixel_height
+        cli_config.pixel_width, cli_config.pixel_height = size
+        try:
+            yield
+        finally:
+            cli_config.pixel_width, cli_config.pixel_height = old_size
+
     # endregion (slots-anim)
 
     # endregion (slots)
@@ -678,7 +806,7 @@ class AnimViewer(QMainWindow):
                                           QUdpSocket.BindFlag.ShareAddress | QUdpSocket.BindFlag.ReuseAddressHint)
             if ret:
                 self.shared_socket.readyRead.connect(self.on_shared_ready_read)
-                log.debug(
+                log.info(
                     _('Searching port has been opened at {port}')
                     .format(port=client_search_port)
                 )
@@ -705,7 +833,7 @@ class AnimViewer(QMainWindow):
 
         self.socket.readyRead.connect(self.on_ready_read)
 
-        self.clients: list[tuple[QHostAddress, int]] = []
+        self.clients: set[tuple[QHostAddress, int]] = set()
         self.lineno = -1
 
         log.info(_('Interactive port has been opened at {port}').format(port=self.socket.localPort()))
@@ -751,7 +879,7 @@ class AnimViewer(QMainWindow):
 
                 match janim['type']:
                     case 'register_client':
-                        self.clients.append((datagram.senderAddress(), datagram.senderPort()))
+                        self.clients.add((datagram.senderAddress(), datagram.senderPort()))
                         self.send_lineno(self.lineno)
 
                     # 重新构建
@@ -777,6 +905,7 @@ class AnimViewer(QMainWindow):
 
     def closeEvent(self, event: QCloseEvent) -> None:
         super().closeEvent(event)
+
         if self.socket is not None:
             msg = json.dumps(dict(
                 janim=dict(
@@ -789,6 +918,8 @@ class AnimViewer(QMainWindow):
                     *client
                 )
 
+        self.save_options()
+
     if sys.platform == "darwin":
         def eventFilter(self, watched, event):
             if self.windowFlags() & Qt.WindowType.WindowStaysOnTopHint:
