@@ -21,7 +21,8 @@ from janim.items.vitem import VItem
 from janim.locale.i18n import get_local_strings
 from janim.logger import log
 from janim.utils.config import Config
-from janim.utils.file_ops import get_janim_dir, get_typst_temp_dir
+from janim.utils.file_ops import (get_janim_dir, get_typst_packages_dir,
+                                  get_typst_temp_dir)
 from janim.utils.iterables import flatten
 from janim.utils.space_ops import rotation_between_vectors
 
@@ -44,25 +45,31 @@ class TypstDoc(SVGItem):
         *,
         vars: dict[str, TypstVar] | None = None,
         vars_size_unit: Literal['pt', 'mm', 'cm', 'in', 'pt'] | None = None,
-        scale: float = 24 / 11,     # 因为 Typst 默认字号=11，janim 默认字号=24，为了默认显示效果一致，将 Typst 内容缩放 24/11
+        sys_inputs: dict[str, str] = {},
+        scale: float = 1.0,
         shared_preamble: str | None = None,
         additional_preamble: str | None = None,
         **kwargs
     ):
         self.text = text
+
+        # 因为 Typst 默认字号=11，janim 默认字号=24，为了默认显示效果一致，将 Typst 内容缩放 24/11
+        scale *= 24 / 11
+
         if shared_preamble is None:
             shared_preamble = Config.get.typst_shared_preamble
         if additional_preamble is None:
             additional_preamble = ''
 
         if vars is not None:
-            factor = Config.get.default_pixel_to_frame_ratio * (FRAME_PPI / 96) * scale
-            vars_str, vars_mapping = self.vars_str(vars, vars_size_unit or 1 / factor)
+            factor_pt = Config.get.default_pixel_to_frame_ratio * (FRAME_PPI / 96) * scale
+            factor_px = factor_pt * 4 / 3
+            vars_str, vars_mapping = self.vars_str(vars, vars_size_unit or 1 / factor_px)
         else:
             vars_str = ''
 
         super().__init__(
-            self.compile_typst(text, shared_preamble, additional_preamble, vars_str),
+            self.compile_typst(text, shared_preamble, additional_preamble, vars_str, sys_inputs),
             scale=scale,
             **kwargs
         )
@@ -79,6 +86,12 @@ class TypstDoc(SVGItem):
                     item_to_replace = item if i == 0 else item.copy()
                     item_to_replace.points.set_size(width=phbox.width, height=phbox.height).move_to(phbox.center)
 
+                    for suborder, sub in enumerate(item_to_replace.walk_self_and_descendants()):
+                        sub.depth._depth = placeholder.depth._depth
+                        sub.depth._order = placeholder.depth._order + 1e-4 * suborder
+
+                    self.groups[label] = [item_to_replace]
+
                     idx = new_children.index(placeholder)
                     new_children.pop(idx)
                     new_children.insert(idx, item_to_replace)
@@ -90,15 +103,27 @@ class TypstDoc(SVGItem):
         self.points.scale(0.9, about_point=ORIGIN).to_border(UP)
 
     @staticmethod
-    def compile_typst(text: str, shared_preamble: str, additional_preamble: str, vars: str) -> str:
+    def compile_typst(
+        text: str,
+        shared_preamble: str,
+        additional_preamble: str,
+        vars: str,
+        sys_inputs: dict[str, str]
+    ) -> str:
         '''
         编译 Typst 文档
         '''
+        sys_inputs_pairs = [
+            f'{key}={value}'
+            for key, value in sys_inputs.items()
+        ]
+
         typst_temp_dir = get_typst_temp_dir()
         md5 = hashlib.md5(text.encode())
         md5.update(shared_preamble.encode())
         md5.update(additional_preamble.encode())
         md5.update(vars.encode())
+        md5.update('\n'.join(sys_inputs_pairs).encode())
         hash_hex = md5.hexdigest()
 
         svg_file_path = os.path.join(typst_temp_dir, hash_hex + '.svg')
@@ -117,9 +142,15 @@ class TypstDoc(SVGItem):
             'compile',
             '-',
             svg_file_path,
-            '-f', 'svg'
+            '-f', 'svg',
+            '--package-path', get_typst_packages_dir()
         ]
 
+        for pair in sys_inputs_pairs:
+            commands += [
+                '--input', pair
+            ]
+
         try:
             process = sp.Popen(commands, stdin=sp.PIPE)
         except FileNotFoundError:
@@ -146,7 +177,7 @@ class TypstDoc(SVGItem):
         return obj if isinstance(obj, TypstDoc) else cls(obj)
 
     @staticmethod
-    def vars_str(vars: dict[str, TypstVar], unit_or_scale: str | int) -> tuple[str, dict[str, Points]]:
+    def vars_str(vars: dict[str, TypstVar], unit_or_scale: str | float) -> tuple[str, dict[str, Points]]:
         mapping = {}
         lst = [
             f'#let {key} = {TypstDoc.var_str(var, f'__ja__{key}', unit_or_scale, mapping)}'
@@ -155,7 +186,7 @@ class TypstDoc(SVGItem):
         return '#let __jabox = box.with(stroke: white)\n' + '\n'.join(lst), mapping
 
     @staticmethod
-    def var_str(var: TypstVar, label: str, unit_or_scale: str | int, mapping: dict[str, Points]) -> str:
+    def var_str(var: TypstVar, label: str, unit_or_scale: str | float, mapping: dict[str, Points]) -> str:
         if isinstance(var, Points):
             width = TypstDoc.length_str(var.points.box.width, unit_or_scale)
             height = TypstDoc.length_str(var.points.box.height, unit_or_scale)
@@ -181,7 +212,7 @@ class TypstDoc(SVGItem):
             )
 
     @staticmethod
-    def length_str(length: float, unit_or_scale: str | int) -> str:
+    def length_str(length: float, unit_or_scale: str | float) -> str:
         if isinstance(unit_or_scale, numbers.Real):
             return f'{length * unit_or_scale}pt'
         elif isinstance(unit_or_scale, str):
