@@ -10,7 +10,7 @@ from janim.components.glow import Cmpt_Glow
 from janim.components.points import Cmpt_Points
 from janim.components.radius import Cmpt_Radius
 from janim.components.rgbas import Cmpt_Rgbas, apart_alpha
-from janim.components.vpoints import Cmpt_VPoints
+from janim.components.vpoints import SCALE_STROKE_RADIUS_KEY, Cmpt_VPoints
 from janim.constants import PI
 from janim.items.item import Item, mockable
 from janim.items.points import Group, Points
@@ -56,6 +56,12 @@ class VItem(Points):
 
         Cmpt_Points.reverse.connect(self.points, reverse)
 
+        Cmpt_Points.apply_points_fn.connect(
+            self.points,
+            lambda factor, root_only: self.radius.scale(factor, root_only=root_only),
+            key=SCALE_STROKE_RADIUS_KEY
+        )
+
     def apply_style(
         self,
         stroke_radius: float | Iterable[float] | None = None,
@@ -111,6 +117,7 @@ class VItem(Points):
         colorize: bool = True,
         fill_color: JAnimColor | None = None,
         stroke_color: JAnimColor | None = None,
+        color: JAnimColor | None = None,
         d_alpha: float = 1e-6,
         **tip_kwargs
     ):
@@ -136,6 +143,11 @@ class VItem(Points):
         if reverse:
             angle += PI
 
+        if fill_color is None and color is not None:
+            fill_color = color
+        if stroke_color is None and color is not None:
+            stroke_color = color
+
         if colorize:
             if fill_color is None:
                 fill_color = self.fill.get()[0, :3]
