@@ -1,4 +1,5 @@
 import os
+import weakref
 
 import moderngl as mgl
 from PIL import Image
@@ -22,14 +23,16 @@ def get_img_from_file(file_path: str) -> Image.Image:
     return img
 
 
-img_to_texture_map: dict[tuple[mgl.Context, int], mgl.Texture] = {}
+# 存在新的 Image 对象与先前已经释放的 Image 对象具有相同 id 的可能
+# 所以这里使用 ref，从而检查 Image 对象是否被释放掉
+img_to_texture_map: dict[tuple[mgl.Context, int], tuple[mgl.Texture, weakref.ref]] = {}
 
 
 def get_texture_from_img(img: Image.Image) -> mgl.Texture:
     ctx = Renderer.data_ctx.get().ctx
     key = (ctx, id(img))
-    texture = img_to_texture_map.get(key, None)
-    if texture is not None:
+    texture, ref = img_to_texture_map.get(key, (None, None))
+    if texture is not None and ref() is not None:
         return texture
     texture = ctx.texture(
         size=img.size,
@@ -38,5 +41,5 @@ def get_texture_from_img(img: Image.Image) -> mgl.Texture:
     )
     texture.repeat_x = False
     texture.repeat_y = False
-    img_to_texture_map[key] = texture
+    img_to_texture_map[key] = (texture, weakref.ref(img))
     return texture
