@@ -33,3 +33,10 @@ class SupportsAnim(Protocol):
     因此用 :class:`SupportsAnim` 作为它们的统称，并会被 `AnimGroup._get_animation_objects` 统一转化
     '''
     def __anim__(self) -> 'Animation': ...
+
+
+def t_(*x):
+    '''
+    提供给 janim-toolbox vscode 插件，用于标注其中包含的字符串需要 Typst 高亮
+    '''
+    return x[0] if len(x) == 1 else x
